==> jc-1.4.0.tar.gz: javax/swing/event/MenuKeyEvent.h <==
// public class javax.swing.event.MenuKeyEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 64c9d020c6e6b8b0 java_awt_event_KeyEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 14a148f6a9080538 javax_swing_event_MenuKeyEvent

// header file dependencies
// @dep_header java_awt_event_KeyEvent

#include "java/awt/event/KeyEvent.h"

#ifndef _JC_javax_swing_event_MenuKeyEvent_H_
#define _JC_javax_swing_event_MenuKeyEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_MenuSelectionManager$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuKeyEvent$sub_refs	_jc_javax_swing_event_MenuKeyEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs	_jc_javax_swing_event_MenuKeyEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$refs	_jc_javax_swing_event_MenuKeyEvent$refs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$nonrefs	_jc_javax_swing_event_MenuKeyEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$object	_jc_javax_swing_event_MenuKeyEvent$object;

typedef const struct _jc_javax_swing_event_MenuKeyEvent$vmethods	_jc_javax_swing_event_MenuKeyEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuKeyEvent$vtable	_jc_javax_swing_event_MenuKeyEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuKeyEvent$vtype	_jc_javax_swing_event_MenuKeyEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuKeyEvent$method$_init$99e4cfa11e323962(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jchar, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *);

// Virtual methods
extern struct _jc_javax_swing_MenuSelectionManager$object *_jc_javax_swing_event_MenuKeyEvent$method$getMenuSelectionManager$aebcc6b5d8605322(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
extern _jc_object_array *_jc_javax_swing_event_MenuKeyEvent$method$getPath$1280a9aa069ec637(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
extern void _jc_javax_swing_event_MenuKeyEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$getMenuSelectionManager$aebcc6b5d8605322;
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$getPath$1280a9aa069ec637;
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_MenuKeyEvent$vmethods {
	struct _jc_javax_swing_MenuSelectionManager$object	*(*getMenuSelectionManager$aebcc6b5d8605322)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
	_jc_object_array	*(*getPath$1280a9aa069ec637)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *);
};

// Vtable
struct _jc_javax_swing_event_MenuKeyEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_KeyEvent$vmethods	java_awt_event_KeyEvent;
	_jc_javax_swing_event_MenuKeyEvent$vmethods	javax_swing_event_MenuKeyEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuKeyEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuKeyEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuKeyEvent$sub_refs {
	_jc_object_array	*path;
	struct _jc_javax_swing_MenuSelectionManager$object	*manager;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuKeyEvent$refs {
    _jc_javax_swing_event_MenuKeyEvent$sub_refs	javax_swing_event_MenuKeyEvent;
    _jc_java_awt_event_KeyEvent$sub_refs	java_awt_event_KeyEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuKeyEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_KeyEvent$sub_nonrefs	java_awt_event_KeyEvent;
    _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs	javax_swing_event_MenuKeyEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuKeyEvent$object {
	_jc_javax_swing_event_MenuKeyEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuKeyEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuKeyEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuKeyEvent$vtype _jc_javax_swing_event_MenuKeyEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuKeyEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuKeyEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuKeyEvent_H_ */

==> jc-1.4.5.tar.gz: javax/swing/event/MenuKeyEvent.h <==
// public class javax.swing.event.MenuKeyEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class eaf34c066b783793 java_awt_event_ComponentEvent
// @dep_class 5b797b166d3f258a java_awt_event_InputEvent
// @dep_class 64c9d020c6e6b8b0 java_awt_event_KeyEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject
// @dep_class 14a148f6a9080538 javax_swing_event_MenuKeyEvent

// header file dependencies
// @dep_header java_awt_event_KeyEvent

#include "java/awt/event/KeyEvent.h"

#ifndef _JC_javax_swing_event_MenuKeyEvent_H_
#define _JC_javax_swing_event_MenuKeyEvent_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_MenuSelectionManager$object;

// Typedefs
typedef struct _jc_javax_swing_event_MenuKeyEvent$sub_refs	_jc_javax_swing_event_MenuKeyEvent$sub_refs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs	_jc_javax_swing_event_MenuKeyEvent$sub_nonrefs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$refs	_jc_javax_swing_event_MenuKeyEvent$refs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$nonrefs	_jc_javax_swing_event_MenuKeyEvent$nonrefs;
typedef struct _jc_javax_swing_event_MenuKeyEvent$object	_jc_javax_swing_event_MenuKeyEvent$object;

typedef const struct _jc_javax_swing_event_MenuKeyEvent$vmethods	_jc_javax_swing_event_MenuKeyEvent$vmethods;
typedef const struct _jc_javax_swing_event_MenuKeyEvent$vtable	_jc_javax_swing_event_MenuKeyEvent$vtable;
typedef const struct _jc_javax_swing_event_MenuKeyEvent$vtype	_jc_javax_swing_event_MenuKeyEvent$vtype;

// Constructors
extern void _jc_javax_swing_event_MenuKeyEvent$method$_init$99e4cfa11e323962(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *, struct _jc_java_awt_Component$object *, jint, jlong, jint, jint, jchar, struct _jc_object_array *, struct _jc_javax_swing_MenuSelectionManager$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_MenuSelectionManager$object *_jc_javax_swing_event_MenuKeyEvent$method$getMenuSelectionManager$aebcc6b5d8605322(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_event_MenuKeyEvent$method$getPath$1280a9aa069ec637(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_event_MenuKeyEvent$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$getMenuSelectionManager$aebcc6b5d8605322;
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$getPath$1280a9aa069ec637;
extern _jc_method _jc_javax_swing_event_MenuKeyEvent$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_javax_swing_event_MenuKeyEvent$vmethods {
	struct _jc_javax_swing_MenuSelectionManager$object	*(*getMenuSelectionManager$aebcc6b5d8605322)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getPath$1280a9aa069ec637)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_javax_swing_event_MenuKeyEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_event_MenuKeyEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
	_jc_java_awt_event_ComponentEvent$vmethods	java_awt_event_ComponentEvent;
	_jc_java_awt_event_InputEvent$vmethods	java_awt_event_InputEvent;
	_jc_java_awt_event_KeyEvent$vmethods	java_awt_event_KeyEvent;
	_jc_javax_swing_event_MenuKeyEvent$vmethods	javax_swing_event_MenuKeyEvent;
};

// Vtype
struct _jc_javax_swing_event_MenuKeyEvent$vtype {
	_jc_type			type;
	_jc_javax_swing_event_MenuKeyEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_event_MenuKeyEvent$sub_refs {
	_jc_object_array	*path;
	struct _jc_javax_swing_MenuSelectionManager$object	*manager;
};

// Reference instance fields (object)
struct _jc_javax_swing_event_MenuKeyEvent$refs {
    _jc_javax_swing_event_MenuKeyEvent$sub_refs	javax_swing_event_MenuKeyEvent;
    _jc_java_awt_event_KeyEvent$sub_refs	java_awt_event_KeyEvent;
    _jc_java_awt_event_InputEvent$sub_refs	java_awt_event_InputEvent;
    _jc_java_awt_event_ComponentEvent$sub_refs	java_awt_event_ComponentEvent;
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_event_MenuKeyEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
    _jc_java_awt_event_ComponentEvent$sub_nonrefs	java_awt_event_ComponentEvent;
    _jc_java_awt_event_InputEvent$sub_nonrefs	java_awt_event_InputEvent;
    _jc_java_awt_event_KeyEvent$sub_nonrefs	java_awt_event_KeyEvent;
    _jc_javax_swing_event_MenuKeyEvent$sub_nonrefs	javax_swing_event_MenuKeyEvent;
};

// Object instance structure
struct _jc_javax_swing_event_MenuKeyEvent$object {
	_jc_javax_swing_event_MenuKeyEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_event_MenuKeyEvent$vtype	*vtype;
	_jc_javax_swing_event_MenuKeyEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_event_MenuKeyEvent$vtype _jc_javax_swing_event_MenuKeyEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_event_MenuKeyEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_event_MenuKeyEvent$class_object;

#endif	/* _JC_javax_swing_event_MenuKeyEvent_H_ */
